Quilt manages data like code (with packages, repositories, browsing and
revision history) so that teams can experiment faster in machine learning,
biotech, and other data-driven domains.

The `quilt3` PyPI package allows you to build, push, and install data packages.
Visit the `documentation quickstart <https://docs.quilt.bio/quickstart>`_
to learn more.
